"""
Shared utility functions and helpers for RAG embedding database application.
"""

from .embedding_utils import cosine_similarity, euclidean_distance, normalize_embedding
from .env_config import get_env_variable, load_env_file, read_env_config, set_env
from .file_utils import extract_random_jsonl_rows, split_jsonl_file
from .identity_utils import get_azure_openai_token
from .rate_limiter import RateLimitConfig, RateLimiter, create_rate_limiter_from_config, get_common_rate_limits

__all__ = [
    "read_env_config",
    "set_env",
    "get_env_variable",
    "load_env_file",
    "get_azure_openai_token",
    "split_jsonl_file",
    "extract_random_jsonl_rows",
    "RateLimiter",
    "RateLimitConfig",
    "create_rate_limiter_from_config",
    "get_common_rate_limits",
    "normalize_embedding",
    "cosine_similarity",
    "euclidean_distance",
]
